@@ -78,7 +78,13 @@ where
         };
         let base = match base {
             FileName::Real(v) => Cow::Borrowed(v),
-            FileName::Anon => Cow::Owned(current_dir().expect("failed to get current directory")),
+            FileName::Anon => {
+                if cfg!(target_arch = "wasm32") {
+                    panic!("Please specify `filename`")
+                } else {
+                    Cow::Owned(current_dir().expect("failed to get current directory"))
+                }
+            }
             _ => {
                 unreachable!(
                     "Node path provider does not support using `{:?}` as a base file name",
